/*
  Tool            Test_getting_linux_terminal_function_result.s
  Author          Carlo Hogeveen
  Compatibility   Linux TSE
  Version         1

  An application running in a Linux terminal can call terminal functions
  by sending certain character strings to STDOUT.
  Some of those functions send result strings back to STDIN.

  This test tool demonstrates how to call such a function
  and how to process its result.

  It uses "getting the terminal's cursor position" as a simple example.

  The exciting part is, that advanced terminals can execute advanced functions.

  The drawback is, that less advanced terminals will not be compatible.

  Bibliography:
    https://en.wikipedia.org/wiki/ANSI_escape_code
    https://invisible-island.net/xterm/ctlseqs/ctlseqs.html
*/

#ifndef LINUX
  This macro only works in LINUX.
#endif

proc Main()
  string  read_result [MAXSTRINGLEN] = ''
  string  result_column          [5] = ''
  string  result_row             [5] = ''

  // Command the terminal to report the cursor position.
  fWrite(_STDOUT_, Chr(27) + '[6n')

  fRead(_STDIN_, read_result, MAXSTRINGLEN)
  result_row    = GetToken(GetToken(read_result, '[', 2), ';', 1)
  result_column = GetToken(GetToken(read_result, ';', 2), 'R', 1)
  Warn('Getting the terminal cursor position ...', Chr(13), Chr(13),
       'Raw result: "', read_result, '"', Chr(13),
       'Row       :'  ; result_row      , Chr(13),
       'Column    :'  ; result_column)

  PurgeMacro(CurrMacroFilename())
end Main

